package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;
import java.util.Arrays;
import org.apache.commons.lang3.ArrayUtils;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/NestMembers.class */
public final class NestMembers extends Attribute {
    private int[] classes;

    /* JADX INFO: Access modifiers changed from: package-private */
    public NestMembers(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
        this(nameIndex, length, (int[]) null, constantPool);
        int classCount = input.readUnsignedShort();
        this.classes = new int[classCount];
        for (int i = 0; i < classCount; i++) {
            this.classes[i] = input.readUnsignedShort();
        }
    }

    public NestMembers(int nameIndex, int length, int[] classes, ConstantPool constantPool) {
        super((byte) 26, nameIndex, length, constantPool);
        this.classes = classes != null ? classes : ArrayUtils.EMPTY_INT_ARRAY;
    }

    public NestMembers(NestMembers c) {
        this(c.getNameIndex(), c.getLength(), c.getClasses(), c.getConstantPool());
    }

    @Override // org.apache.bcel.classfile.Attribute, org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitNestMembers(this);
    }

    @Override // org.apache.bcel.classfile.Attribute
    public Attribute copy(ConstantPool constantPool) {
        NestMembers c = (NestMembers) clone();
        if (this.classes != null) {
            c.classes = (int[]) this.classes.clone();
        }
        c.setConstantPool(constantPool);
        return c;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public void dump(DataOutputStream file) throws IOException {
        super.dump(file);
        file.writeShort(this.classes.length);
        for (int index : this.classes) {
            file.writeShort(index);
        }
    }

    public int[] getClasses() {
        return this.classes;
    }

    public String[] getClassNames() {
        String[] names = new String[this.classes.length];
        Arrays.setAll(names, i -> {
            return Utility.pathToPackage(super.getConstantPool().getConstantString(this.classes[i], (byte) 7));
        });
        return names;
    }

    public int getNumberClasses() {
        if (this.classes == null) {
            return 0;
        }
        return this.classes.length;
    }

    public void setClasses(int[] classes) {
        this.classes = classes != null ? classes : ArrayUtils.EMPTY_INT_ARRAY;
    }

    @Override // org.apache.bcel.classfile.Attribute
    public String toString() {
        StringBuilder buf = new StringBuilder();
        buf.append("NestMembers(");
        buf.append(this.classes.length);
        buf.append("):\n");
        for (int index : this.classes) {
            String className = super.getConstantPool().getConstantString(index, (byte) 7);
            buf.append("  ").append(Utility.compactClassName(className, false)).append("\n");
        }
        return buf.substring(0, buf.length() - 1);
    }
}
